@@ -1,4 +1,4 @@
-from flask import request
+from flask import request, abort
 from flask_restx import Api, Resource
 import actelink.models as models
 
@@ -13,6 +13,6 @@ class Computations(Resource):
     def post(self):
         data = request.get_json()
         res = models.compute(data)
-        if len(res) == 0:
-            return [], 400
+        if len(res["results"]) == 0:
+            abort(400, "no function registered for these contexts")
         return res, 200
